# Snakemake Storage Plugin GS

> A snakemake 🐍️ storage plugin for Google Cloud Storage

**under development**

This plugin is in draft form, and not tested yet!
This is scaffolded from [snakemake/poetry-snakemake-plugin](https://github.com/snakemake/poetry-snakemake-plugin).

## License

HPCIC DevTools is distributed under the terms of the MIT license.
All new contributions must be made under this license.

See [LICENSE](https://github.com/converged-computing/cloud-select/blob/main/LICENSE),
[COPYRIGHT](https://github.com/converged-computing/cloud-select/blob/main/COPYRIGHT), and
[NOTICE](https://github.com/converged-computing/cloud-select/blob/main/NOTICE) for details.

SPDX-License-Identifier: (MIT)

LLNL-CODE- 842614
